import { build } from 'esbuild';
import { rm, writeFile } from 'fs/promises';
import { resolve } from 'node:path';
import { PLUGIN_DIR, PLUGIN_NAME, PLUGIN_VERSION, SERVER_HANDLER_DIR, SERVER_HANDLER_NAME, } from '../constants.js';
import { copyServerContent, copyServerDependencies } from '../content/server.js';
/**
 * Create a Netlify function to run the Next.js server
 */
export const createServerHandler = async ({ constants: { PUBLISH_DIR }, }) => {
    // reset the handler directory
    await rm(resolve(SERVER_HANDLER_DIR), { recursive: true, force: true });
    // copy the next.js standalone build output to the handler directory
    await copyServerContent(resolve(PUBLISH_DIR, 'standalone/.next'), resolve(SERVER_HANDLER_DIR, '.next'));
    await copyServerDependencies(resolve(PUBLISH_DIR, 'standalone/node_modules'), resolve(SERVER_HANDLER_DIR, 'node_modules'));
    // configure ESM
    await writeFile(resolve(SERVER_HANDLER_DIR, 'package.json'), JSON.stringify({ type: 'module' }));
    // create the handler metadata file
    await writeFile(resolve(SERVER_HANDLER_DIR, `${SERVER_HANDLER_NAME}.json`), JSON.stringify({
        config: {
            name: 'Next.js Server Handler',
            generator: `${PLUGIN_NAME}@${PLUGIN_VERSION}`,
            nodeBundler: 'none',
            includedFiles: ['**', '.*/**'],
            includedFilesBasePath: resolve(SERVER_HANDLER_DIR),
        },
        version: 1,
    }), 'utf-8');
    await build({
        entryPoints: [resolve(PLUGIN_DIR, 'dist/run/handlers/server.js')],
        bundle: true,
        platform: 'node',
        target: ['node18'],
        format: 'esm',
        external: ['next'],
        banner: {
            js: "import { createRequire } from 'module';const require = createRequire(import.meta.url);",
        },
        footer: { js: 'export default serverHandler' },
        outfile: resolve(SERVER_HANDLER_DIR, `${SERVER_HANDLER_NAME}.js`),
    });
    await build({
        entryPoints: [resolve(PLUGIN_DIR, 'dist/run/handlers/cache.cjs')],
        bundle: true,
        platform: 'node',
        target: ['node18'],
        format: 'cjs',
        external: ['next'],
        outfile: resolve(SERVER_HANDLER_DIR, 'cache.cjs'),
    });
};
